import{r as u,av as v,j as a,v as R,aJ as f,ax as c}from"./index-2a796b7e.js";function m(s){let i=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"content";const o=u(),n=u();if(v){const t=new ResizeObserver(e=>{s==null||s(e,t),e.length&&(i==="content"?n.value=e[0].contentRect:n.value=e[0].target.getBoundingClientRect())});a(()=>{t.disconnect()}),R(o,(e,r)=>{r&&(t.unobserve(f(r)),n.value=void 0),e&&t.observe(f(e))},{flush:"post"})}return{resizeRef:o,contentRect:c(n)}}export{m as u};
