import{M as p,aC as d,c as f,X as v,l,S as _,J as t,w as a,O as g,Q as V,_ as r,$ as s,P as h,m as b,Y as B}from"./index-2a796b7e.js";import{V as C}from"./VToolbar-343cf9b8.js";import{V as S}from"./VDivider-d71a9ada.js";import{a as T,V as n}from"./VTabs-642daec8.js";import"./VImg-9fff8259.js";import"./index-bfe34a20.js";import"./VBtn-29a0de88.js";import"./forwardRefs-ab2b038b.js";import"./VProgressCircular-57c5ac59.js";import"./resizeObserver-a1e84c0c.js";import"./VSlideGroup-74f16a52.js";const $=V("div",{style:{height:"15px"}},null,-1),Q=p({__name:"Settings",setup(k){const i=d(),c=f(()=>{var e,o;return(e=i.currentRoute.value.name)!=null&&e.toString().includes("forecast")?"forecast":(o=i.currentRoute.value.name)!=null&&o.toString().includes("core")?"core":"devices"});return(e,o)=>{const u=v("router-view");return l(),_("div",null,[t(C,{color:"transparent",title:g(h)("bp4")?e.$t("app.settings"):""},{append:a(()=>[t(T,{"model-value":c.value,"align-tabs":"end",height:"100%"},{default:a(()=>[t(n,{value:"devices",to:{name:"devicessettings"}},{default:a(()=>[r(s(e.$t("settings.devices")),1)]),_:1}),t(n,{value:"forecast",to:{name:"forecastsettings"}},{default:a(()=>[r(s(e.$t("settings.forecast")),1)]),_:1}),t(n,{value:"core",to:{name:"coresettings"}},{default:a(()=>[r(s(e.$t("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),t(S),$,t(u,null,{default:a(({Component:m})=>[(l(),b(B(m)))]),_:1})])}}});export{Q as default};
