import{a as c,j as f,c as y,q as V,d as k,o as P,r as C,k as S,g as z,s as h,i as A,B as x,V as B,x as I,w as R}from"./VImg-9fff8259.js";import{z as o,aR as D,aQ as T,a9 as F,p as _,af as j,y as q,B as w,J as l}from"./index-2a796b7e.js";function Q(a){let r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"div",e=arguments.length>2?arguments[2]:void 0;return o()({name:e??D(T(a.replace(/__/g,"-"))),props:{tag:{type:String,default:r},...c()},setup(t,u){let{slots:s}=u;return()=>{var n;return F(t.tag,{class:[a,t.class],style:t.style},(n=s.default)==null?void 0:n.call(s))}}})}const J=_({start:Boolean,end:Boolean,icon:j,image:String,text:String,...c(),...f(),...y(),...V(),...k(),...q(),...P({variant:"flat"})},"VAvatar"),$=o()({name:"VAvatar",props:J(),setup(a,r){let{slots:e}=r;const{themeClasses:t}=w(a),{colorClasses:u,colorStyles:s,variantClasses:n}=C(a),{densityClasses:m}=S(a),{roundedClasses:v}=z(a),{sizeClasses:d,sizeStyles:g}=h(a);return A(()=>l(a.tag,{class:["v-avatar",{"v-avatar--start":a.start,"v-avatar--end":a.end},t.value,u.value,m.value,v.value,d.value,n.value,a.class],style:[s.value,g.value,a.style]},{default:()=>[e.default?l(I,{key:"content-defaults",defaults:{VAvatar:{cover:!0,image:a.image},VIcon:{icon:a.icon}}},{default:()=>{var i;return[(i=e.default)==null?void 0:i.call(e)]}}):a.image?l(x,{key:"image",src:a.image,alt:"",cover:!0},null):a.icon?l(B,{key:"icon",icon:a.icon},null):a.text,R(!1,"v-avatar")]})),{}}});export{$ as V,Q as c};
